package Linode::Longview::DataGetter::Packages::APT;

use Linux::APT;
use 5.010;
use feature 'state';

use Linode::Longview::Util;

sub get {
	my ( undef, $dataref ) = @_;

	$logger->trace('Entering APT module');

	if(check_running($dataref)){
		$logger->debug('Another instance of apt-get is already running, skip package this pass');
		$dataref->{INSTANT}->{Packages} = [];
		return $dataref;
	}
	my $apt = Linux::APT->new();
	if(should_update()){
		$logger->trace('Running apt-get update before reporting packages');
		$apt->update();
	}
	my $pkgs = $apt->toupgrade()->{packages};
	$dataref->{INSTANT}->{Packages} = [
		map {
			{   name    => $_,
				current => $pkgs->{$_}{current},
				new     => $pkgs->{$_}{new} }
		} keys %$pkgs
	];
	return $dataref;
}

sub should_update {
	state $next_run;
	return 0 if((defined $next_run) && ($next_run > time));
	$next_run = time + 86400; #Only actually hit the mirrors once every 24 hours.
	return 1;
}

sub check_running {
	my $dataref = shift;
	return grep(m/Processes\.apt(?:-get|itude)/,keys %{$dataref->{LONGTERM}});
}

1;
