package Linode::Longview::DataGetter::SysInfo;

use Sys::Hostname;

use Linode::Longview::Util ':SYSINFO';
use Linux::Distribution qw(distribution_name distribution_version);
use POSIX 'uname';

sub get {
	my (undef, $dataref) = @_;
	$logger->trace('Collecting SysInfo');

	$dataref->{INSTANT}->{'SysInfo.os.dist'}			= 'unknown';
	$dataref->{INSTANT}->{'SysInfo.os.distversion'} 	= 'unknown';
	if ( my $distro = distribution_name() ) {
		$dataref->{INSTANT}->{'SysInfo.os.dist'} 		= ucfirst($distro);
		$dataref->{INSTANT}->{'SysInfo.os.distversion'} = distribution_version();
	}

	$dataref->{INSTANT}->{'SysInfo.client'} = $VERSION;

	my ( $sysname, undef, $release, $version, $machine ) = uname();
	$dataref->{INSTANT}->{'SysInfo.kernel'}   = "$sysname $release";
	$dataref->{INSTANT}->{'SysInfo.type'}     = detect_system();
	$dataref->{INSTANT}->{'SysInfo.arch'}     = $ARCH;
	$dataref->{INSTANT}->{'SysInfo.hostname'} = hostname;

	my @cpu_info = slurp_file( $PROCFS . 'cpuinfo' )
		or do {
			$logger->info("Couldn't read ${PROCFS}cpuinfo: $!");
			return $dataref;
	};

	$dataref->{INSTANT}->{'SysInfo.cpu.cores'} = grep {/^processor/} @cpu_info;
	#<<<
	($dataref->{INSTANT}->{'SysInfo.cpu.type'} =
		(map { /^model name\s+:(?<model>.*)$/; $+{model} || ()} @cpu_info)[0])
		=~ s/^\s+//;
	#>>>
	$dataref->{INSTANT}->{'SysInfo.cpu.type'} =~ s/\s{2,}/ /g;
	$dataref->{INSTANT}->{Uptime} =
		( split( /\s+/, slurp_file( $PROCFS . 'uptime' ) ) )[0] or
		$logger->info("Couldn't check ${PROCFS}uptime: $!");

	$dataref->{INSTANT}->{Uptime} = $dataref->{INSTANT}->{Uptime} +0;

	return $dataref;
}

1;
